{% load cms_tags %}
<div class="{% if not grid.inner %}container-{{ GRID_SIZE }} {% endif %}{% if grid.custom_classes %}{{ grid.custom_classes }} {% endif %}clearfix">
{% for plugin in grid.child_plugin_instances %}
	{% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
{% endfor %}
</div>